@@ -1,52 +1,62 @@
 package org.gcube.portlets.widgets.ckandatapublisherwidget.server;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Calendar;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 
 import javax.servlet.http.HttpSession;
 
-import org.gcube.application.framework.core.session.ASLSession;
-import org.gcube.application.framework.core.session.SessionManager;
-import org.gcube.datacatalogue.ckanutillibrary.DataCatalogue;
-import org.gcube.datacatalogue.ckanutillibrary.DataCatalogueFactory;
-import org.gcube.datacatalogue.ckanutillibrary.models.ResourceBean;
-import org.gcube.datacatalogue.ckanutillibrary.utils.SessionCatalogueAttributes;
-import org.gcube.datacatalogue.ckanutillibrary.utils.UtilMethods;
-import org.gcube.portal.custom.scopemanager.scopehelper.ScopeHelper;
+import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogue;
+import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogueFactory;
+import org.gcube.datacatalogue.ckanutillibrary.server.models.ResourceBean;
+import org.gcube.datacatalogue.ckanutillibrary.server.utils.SessionCatalogueAttributes;
+import org.gcube.datacatalogue.ckanutillibrary.server.utils.UtilMethods;
+import org.gcube.datacatalogue.ckanutillibrary.shared.RolesCkanGroupOrOrg;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.CKanPublisherService;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.server.threads.AssociationToGroupAndNotifyThread;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.server.threads.WritePostCatalogueManagerThread;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.Utils;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.WorkspaceUtils;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DatasetMetadataBean;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.GroupBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.LicensesBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.MetaDataProfileBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.OrganizationBean;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.ResourceBeanWrapper;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.ResourceElementBean;
+import org.gcube.vomanagement.usermanagement.GroupManager;
 import org.gcube.vomanagement.usermanagement.UserManager;
+import org.gcube.vomanagement.usermanagement.exception.GroupRetrievalFault;
+import org.gcube.vomanagement.usermanagement.exception.UserManagementSystemException;
+import org.gcube.vomanagement.usermanagement.impl.LiferayGroupManager;
 import org.gcube.vomanagement.usermanagement.impl.LiferayUserManager;
 import org.gcube.vomanagement.usermanagement.model.GCubeUser;
-import org.slf4j.LoggerFactory;
 
 import com.google.gwt.user.server.rpc.RemoteServiceServlet;
+import com.liferay.portal.kernel.log.Log;
+import com.liferay.portal.kernel.log.LogFactoryUtil;
 import com.liferay.portal.service.UserLocalServiceUtil;
 
+import eu.trentorise.opendata.jackan.model.CkanGroup;
 import eu.trentorise.opendata.jackan.model.CkanLicense;
 
 /**
  * Server side of the data publisher.
  * @author Costantino Perciante at ISTI-CNR (costantino.perciante@isti.cnr.it)
  */
-@SuppressWarnings("serial")
 public class CKANPublisherServicesImpl extends RemoteServiceServlet implements CKanPublisherService{
 
-	// Logger
-	private static final org.slf4j.Logger logger = LoggerFactory.getLogger(CKANPublisherServicesImpl.class);
+	private static final long serialVersionUID = 7252248774050361697L;
 
-	public static final String TEST_SCOPE = "/gcube/devsec/devVRE";
-	public static final String TEST_USER = "test.user";
-	private final static String TEST_SEC_TOKEN = "a1e19695-467f-42b8-966d-bf83dd2382ef";
+	// Logger
+	//private static final org.slf4j.Logger logger = LoggerFactory.getLogger(CKANPublisherServicesImpl.class);
+	private static final Log logger = LogFactoryUtil.getLog(CKANPublisherServicesImpl.class);
+	private static final String PRODUCT_URL_FIELD = "Product URL";
 
 	// map <orgName, scope>
 	private ConcurrentHashMap<String, String> mapOrganizationScope = new ConcurrentHashMap<String, String>();
@@ -59,110 +69,30 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	public DataCatalogue getCatalogue(String scope){
 
 		DataCatalogue instance = null;
+		String scopeInWhichDiscover = null;
 		try{
-			String scopeInWhichDiscover = (scope != null && !scope.isEmpty()) ? scope : getASLSession().getScope();
+			scopeInWhichDiscover = (scope != null && !scope.isEmpty()) ? scope : Utils.getCurrentContext(getThreadLocalRequest(), false);
 			logger.debug("Discovering ckan instance into scope " + scopeInWhichDiscover);
 			instance = DataCatalogueFactory.getFactory().getUtilsPerScope(scopeInWhichDiscover);
 		}catch(Exception e){
-			logger.error("Unable to retrieve ckan utils", e);
+			logger.warn("Unable to retrieve ckan utils in scope " + scopeInWhichDiscover + ". Error is " + e.getLocalizedMessage());
 		}
 		return instance;
 	}
 
 	/**
-	 * the current ASLSession
-	 * @return the session
-	 */
-	private ASLSession getASLSession() {
-		String sessionID = this.getThreadLocalRequest().getSession().getId();
-		String user = (String) this.getThreadLocalRequest().getSession().getAttribute(ScopeHelper.USERNAME_ATTRIBUTE);
-
-		if (user == null) {
-			logger.warn("USER IS NULL setting testing user and Running OUTSIDE PORTAL");
-			user = getDevelopmentUser();
-			SessionManager.getInstance().getASLSession(sessionID, user).setScope(TEST_SCOPE);
-		}		
-		return SessionManager.getInstance().getASLSession(sessionID, user);
-	}
-
-	/**
-	 * when packaging test will fail if the user is not set to test.user
-	 * @return .
-	 */
-	public String getDevelopmentUser() {
-		String user = TEST_USER;
-		//		user = "costantino.perciante";
-		return user;
-	}
-
-	/**
-	 * Get current user's token (for a given scope)
-	 * @param scope if it is not specified it will be retrieved from the asl
-	 * @return String the ckan user's token
-	 */
-	private String getUserCKanTokenFromSession(String scope){
-
-		String token = null;
-
-		if(!isWithinPortal()){
-			logger.warn("You are running outside the portal");
-			token = TEST_SEC_TOKEN;
-		}else{
-
-			ASLSession aslSession = getASLSession();
-			String username = aslSession.getUsername();
-
-			// store info in the http session
-			HttpSession httpSession = getThreadLocalRequest().getSession();
-
-			// check the scope we need to discover
-			String scopeInWhichDiscover = (scope != null && !scope.isEmpty()) ? scope : getASLSession().getScope();
-
-			// get the key per scope
-			String keyPerScope = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_TOKEN_KEY, scopeInWhichDiscover);
-
-			// check if session expired
-			if(username.equals(TEST_USER)){
-
-				logger.warn("Session expired, returning null token");
-				token = null;
-
-			}else{
-				try{
-					logger.debug("User in session is " + username);
-					if(httpSession.getAttribute(keyPerScope) != null){
-						token = (String)httpSession.getAttribute(keyPerScope);
-						logger.debug("Found ckan token into session");
-					}
-					else{
-						token = getCatalogue(scopeInWhichDiscover).getApiKeyFromUsername(username);
-						httpSession.setAttribute(keyPerScope, token);
-						logger.debug("Ckan token has been set for user " + username);
-					}
-					logger.debug("Found ckan token " + token.substring(0, 3) + "************************" + 
-							" for user " + username + " into scope " + scopeInWhichDiscover);
-				}catch(Exception e){
-					logger.error("Error while retrieving the key" , e);
-				}
-			}
-		}
-		return token;
-	}
-
-	/**
-	 * Retrieve the list of organizations in which the user can publish (roles ADMIN)
+	 * Retrieve the list of organizations in which the user can publish (roles ADMIN/EDITOR)
 	 * @param username
 	 * @return the list of organizations
+	 * @throws GroupRetrievalFault 
+	 * @throws UserManagementSystemException 
 	 */
-	private List<OrganizationBean> getUserOrganizationsListAdmin(String username, String scope) {
+	private List<OrganizationBean> getUserOrganizationsListAdmin(String username, String scope) throws UserManagementSystemException, GroupRetrievalFault {
 
 		logger.debug("Request for user " + username + " organizations list");
 		List<OrganizationBean> orgsName = new ArrayList<OrganizationBean>();
 
-		// get http session
 		HttpSession httpSession = getThreadLocalRequest().getSession();
-
-		// get key 
 		String keyPerScope = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_ORGANIZATIONS_PUBLISH_KEY, scope);
 
 		if(httpSession.getAttribute(keyPerScope) != null){
@@ -170,7 +100,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			logger.info("List of organizations was into session " + orgsName);
 		}
 		else{
-			orgsName = Utils.getUserOrganizationsListAdminEditor(scope, username, getASLSession().getGroupName(), this);
+			Utils.getHighestRole(scope, username, Utils.getGroupFromScope(scope).getGroupName(), this, orgsName);
 			httpSession.setAttribute(keyPerScope, orgsName);
 			logger.info("Organizations name for user " + username + " has been saved into session " + orgsName);
 		}
@@ -200,7 +130,8 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	 */
 	private String findLicenseIdByLicense(String chosenLicense) {	
 
-		String scope = (String)getThreadLocalRequest().getSession().getAttribute(SessionCatalogueAttributes.SCOPE_CLIENT_PORTLET_URL);
+		// get scope from client url
+		String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
 		return getCatalogue(scope).findLicenseIdByLicenseTitle(chosenLicense);
 
 	}
@@ -208,22 +139,16 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	@Override
 	public LicensesBean getLicenses() {
 
-		ASLSession session = getASLSession();
-		String username = session.getUsername();
-
 		// get http session
 		HttpSession httpSession = getThreadLocalRequest().getSession();
-		String scope = (String)httpSession.getAttribute(SessionCatalogueAttributes.SCOPE_CLIENT_PORTLET_URL);
-
+		String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
 		logger.info("Request for CKAN licenses for scope " + scope);
-
-		// get key per scope
 		String keyPerScope = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_LICENSES_KEY, scope);
 
 		LicensesBean licensesBean = null;
 		if(httpSession.getAttribute(keyPerScope) != null){
 			licensesBean = (LicensesBean)httpSession.getAttribute(keyPerScope);
-			logger.debug("List of licenses was into session");
+			logger.info("List of licenses was into session");
 		}
 		else{
 			List<CkanLicense> titlesLicenses = getCatalogue(scope).getLicenses();
@@ -236,39 +161,31 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			}
 			licensesBean = new LicensesBean(titles, urls);
 			httpSession.setAttribute(keyPerScope, licensesBean);
-			logger.debug("List of licenses has been saved into session");
+			logger.info("List of licenses has been saved into session");
 		}
 
 		return licensesBean;
+
 	}
 
 	@Override
 	public DatasetMetadataBean getDatasetBean(String folderId){
 
 		DatasetMetadataBean bean = null;
-
-		ASLSession aslSession = getASLSession();
-		String userName = aslSession.getUsername();
+		String userName = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
 
 		logger.info("DatasetBean request for " + folderId + " and " + userName);
 
-		HttpSession httpSession = this.getThreadLocalRequest().getSession();
-		String scope = (String)httpSession.getAttribute(SessionCatalogueAttributes.SCOPE_CLIENT_PORTLET_URL);
-
-		logger.debug("Scope recovered from session is " + scope);
-
 		if(isWithinPortal()){
 			try{
 
-				// check if session expired
-				if(userName.equals(TEST_USER)){
-					logger.debug("SESSION EXPIRED");
-					return null;
-				}
+				String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+
+				logger.debug("Scope recovered from session is " + scope);
 
 				logger.debug("Request dataset metadata bean for folder with id " + folderId
 						+ " whose owner is " + userName);
-				// get usermanager (liferay)
+
 				UserManager liferUserManager = new LiferayUserManager();
 				GCubeUser userOwner = liferUserManager.getUserByUsername(userName);
 
@@ -288,9 +205,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 				// if the request comes from the workspace
 				if(folderId != null && !folderId.isEmpty()){
-
 					WorkspaceUtils.handleWorkspaceResources(folderId, userName, bean);
-
 				}
 
 			}catch(Exception e){
@@ -299,7 +214,6 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		}else{
 
 			try{
-
 				bean = new DatasetMetadataBean();
 				bean.setId(folderId);
 				bean.setDescription("This is a fantastic description");
@@ -311,15 +225,12 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				bean.setAuthorEmail("costantino.perciante@isti.cnr.it");
 				bean.setMaintainer("Costantino Perciante");
 				bean.setMaintainerEmail("costantino.perciante@isti.cnr.it");
-				bean.setOrganizationList(getUserOrganizationsListAdmin(userName, TEST_SCOPE));
+				bean.setOrganizationList(getUserOrganizationsListAdmin(userName, Utils.getCurrentContext(getThreadLocalRequest(), true)));
 				bean.setOwnerIdentifier(userName);
 
 				if(folderId != null && !folderId.isEmpty()){
-
 					WorkspaceUtils.handleWorkspaceResources(folderId, userName, bean);
-
 				}
-
 			}catch(Exception e){
 				logger.error("Error while building bean into dev mode", e);
 			}
@@ -333,17 +244,10 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 		logger.debug("Request for creating a dataset with these information " + toCreate);
 
-		ASLSession aslSession = getASLSession();
-		String userName = aslSession.getUsername();
+		String userName = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
 
 		try{
 
-			// check if session expired
-			if(userName.equals(TEST_USER)){
-				logger.debug("SESSION EXPIRED");
-				return null;
-			}
-
 			String title = toCreate.getTitle();
 			String organizationNameOrId = toCreate.getSelectedOrganization();
 			String author = toCreate.getAuthorFullName();
@@ -355,52 +259,61 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			String chosenLicense = toCreate.getLicense();
 			String licenseId = findLicenseIdByLicense(chosenLicense);
 			List<String> listOfTags = toCreate.getTags();
-			Map<String, String> customFields = toCreate.getCustomFields();
+			Map<String, List<String>> customFields = toCreate.getCustomFields();
 			boolean setPublic = toCreate.getVisibility();
 
 			// get the list of resources and convert to ResourceBean
 			List<ResourceBean> resources = null;
-			List<ResourceBeanWrapper> resourcesToAdd = toCreate.getResources();
+			List<ResourceElementBean> resourcesToAdd = toCreate.getResources();
 
 			// we need to copy such resource in the .catalogue area of the user's ws
 			if(resourcesToAdd != null && !resourcesToAdd.isEmpty()){
-
-				resources = WorkspaceUtils.copyResourcesToUserCatalogueArea(resourcesToAdd, toCreate.getId(), userName, toCreate);
-
+				resources = WorkspaceUtils.copyResourcesToUserCatalogueArea(toCreate.getId(), userName, toCreate);
 			}
 
 			logger.debug("The user wants to publish in organization with name " + organizationNameOrId);
 			String scope = getScopeFromOrgName(organizationNameOrId);
 			DataCatalogue utils = getCatalogue(scope);
+			String userApiKey = utils.getApiKeyFromUsername(userName);
 
-			String datasetId = utils.createCKanDataset(getUserCKanTokenFromSession(scope), title, organizationNameOrId,  author,
-					authorMail,  maintainer,  maintainerMail,  version, description, licenseId,
-					listOfTags, customFields, resources, setPublic);
+			String datasetId = utils.createCKanDatasetMultipleCustomFields
+					(userApiKey, title, null, organizationNameOrId, author, authorMail, maintainer, 
+							maintainerMail, version, description, licenseId, listOfTags, customFields, resources, setPublic);
 
 			if(datasetId != null){
 
-				logger.debug("Dataset created!");
+				logger.info("Dataset created!");
 				toCreate.setId(datasetId);
 
 				// retrieve the url
-				String datasetUrl =  utils.getPortletUrl() + "?path=" +  utils.getUrlFromDatasetIdOrName(getUserCKanTokenFromSession(scope), datasetId, true);
+				String datasetUrl =  utils.getUnencryptedUrlFromDatasetIdOrName(datasetId);
 				toCreate.setSource(datasetUrl);
 
-				// start a thread that will associate this dataset with the group
-				if(toCreate.getChosenProfile() != null){
+				// add also this information as custom field
+				Map<String, List<String>> addField = new HashMap<String, List<String>>();
+				addField.put(PRODUCT_URL_FIELD, Arrays.asList(datasetUrl));
+				utils.patchProductCustomFields(datasetId, userApiKey, addField);
 
-					AssociationToGroupThread threadAssociationToGroup = 
-							new AssociationToGroupThread(
+				// start a thread that will associate this dataset with the group
+				if(toCreate.getChosenProfile() != null || toCreate.getGroups() != null){
+
+					AssociationToGroupAndNotifyThread threadAssociationToGroup = 
+							new AssociationToGroupAndNotifyThread(
+									toCreate.getGroups(),
 									toCreate.getChosenProfile(), 
-									datasetId, 
+									datasetUrl,
+									datasetId,
+									toCreate.getTitle(),
+									Utils.getCurrentUser(getThreadLocalRequest()).getFullname(),
 									userName, 
 									utils, 
-									organizationNameOrId
+									organizationNameOrId,
+									getThreadLocalRequest()
 									);
 					threadAssociationToGroup.start();
 
 				}
-				
+
 				// launch notification thread
 				WritePostCatalogueManagerThread threadWritePost = 
 						new WritePostCatalogueManagerThread(
@@ -408,33 +321,25 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 								scope, 
 								toCreate.getTitle(), 
 								datasetUrl, 
-								true, // send notification to other people 
+								false, // send notification to other people 
 								toCreate.getTags(), 
-								toCreate.getAuthorFullName()
+								Utils.getCurrentUser(getThreadLocalRequest()).getFullname()
 								);
 				threadWritePost.start();
 
 				return toCreate;
-
 			}else{
-
 				logger.error("Failed to create the dataset");
-
 			}
-
 		}catch(Exception e){
 			logger.error("Unable to create the dataset", e);
 		}
-
 		return null;
 	}
 
 	@Override
-	public ResourceBeanWrapper addResourceToDataset(ResourceBeanWrapper resource, String datasetId) {
-
-
-		ASLSession session = getASLSession();
-		String username = session.getUsername();
+	public ResourceElementBean addResourceToDataset(ResourceElementBean resource, String datasetId) {
+		String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
 
 		logger.debug("Incoming request for creating new resource for dataset with id " + datasetId + " and organization name of the dataset is " + resource.getOrganizationNameDatasetParent());
 		logger.debug("Owner is " + username + " and resource is " + resource);
@@ -446,44 +351,38 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 		}else{
 
-			if(username.equals(TEST_USER)){
+			try{
+				ResourceBean resourceBean = new ResourceBean(
+						resource.getUrl(), 
+						resource.getName(), 
+						resource.getDescription(), 
+						null, 
+						username, 
+						datasetId,
+						null);
 
-				logger.warn("SESSION EXPIRED! ");
-				return null;
+				// get the scope in which we should discover the ckan instance given the organization name in which the dataset was created
+				String scope = getScopeFromOrgName(resource.getOrganizationNameDatasetParent());
+				DataCatalogue catalogue = getCatalogue(scope);
+				String resourceId = catalogue.addResourceToDataset(resourceBean, catalogue.getApiKeyFromUsername(username));
 
-			}else{
-				try{
-
-					ResourceBean resourceBean = new ResourceBean(
-							resource.getUrl(), 
-							resource.getName(), 
-							resource.getDescription(), 
-							null, 
-							username, 
-							datasetId,
-							null);
-
-					// get the scope in which we should discover the ckan instance given the organization name in which the dataset was created
-					String scope = getScopeFromOrgName(resource.getOrganizationNameDatasetParent());
-					String resourceId = getCatalogue(scope).addResourceToDataset(resourceBean, getUserCKanTokenFromSession(scope));
-
-					if(resourceId != null){
-						logger.debug("Resource  " + resource.getName() + " is now available");
-						// set its id and turn it to the client
-						resource.setId(resourceId);
-						return resource;
-					}
-				}catch(Exception e){
-					logger.error("Unable to create new resource", e);
+				if(resourceId != null){
+					logger.debug("Resource  " + resource.getName() + " is now available");
+					// set its id and turn it to the client
+					resource.setOriginalIdInWorkspace(resourceId);
+					return resource;
 				}
+			}catch(Exception e){
+				logger.error("Unable to create new resource", e);
 			}
+
 			logger.debug("No resource created");
 			return null;
 		}
 	}
 
 	@Override
-	public boolean deleteResourceFromDataset(ResourceBeanWrapper resource) {
+	public boolean deleteResourceFromDataset(ResourceElementBean resource) {
 
 		logger.debug("Request for deleting resource " + resource);
 		boolean deleted = false;
@@ -493,27 +392,22 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			return deleted;
 		}else{
 
-			ASLSession session = getASLSession();
-			String username = session.getUsername();
-
-			if(username.equals(TEST_USER)){
-				logger.warn("SESSION EXPIRED!");
-				return deleted;
-			}else{
-				try{
-					// get the scope in which we should discover the ckan instance given the organization name in which the dataset was created
-					String scope = getScopeFromOrgName(resource.getOrganizationNameDatasetParent());
-					deleted = getCatalogue(scope).
-							deleteResourceFromDataset(resource.getId(), getUserCKanTokenFromSession(scope));
-					if(deleted){
-						logger.debug("Resource described by " + resource + " deleted");
-					}else
-						logger.error("Resource described by " + resource + " NOT deleted");
-				}catch(Exception e){
-					logger.error("Error while trying to delete resource described by " + resource, e);
-				}
-				return deleted;
+			String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+			try{
+				// get the scope in which we should discover the ckan instance given the organization name in which the dataset was created
+				String scope = getScopeFromOrgName(resource.getOrganizationNameDatasetParent());
+				DataCatalogue catalogue = getCatalogue(scope);
+				deleted = catalogue.
+						deleteResourceFromDataset(resource.getOriginalIdInWorkspace(), catalogue.getApiKeyFromUsername(username));
+				if(deleted){
+					logger.info("Resource described by " + resource + " deleted");
+				}else
+					logger.error("Resource described by " + resource + " NOT deleted");
+			}catch(Exception e){
+				logger.error("Error while trying to delete resource described by " + resource, e);
 			}
+			return deleted;
+
 		}
 	}
 
@@ -521,12 +415,11 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	public List<MetaDataProfileBean> getProfiles(String orgName) {
 
 		logger.debug("Requested profiles for products into orgName " + orgName);
-
 		List<MetaDataProfileBean> toReturn = new ArrayList<MetaDataProfileBean>();
 		try{
 			String evaluatedScope = getScopeFromOrgName(orgName);
 			logger.debug("Evaluated scope is  " + evaluatedScope);
-			toReturn = Utils.getMetadataProfilesList(evaluatedScope, getThreadLocalRequest().getSession(), getASLSession());
+			toReturn = Utils.getMetadataProfilesList(evaluatedScope, getThreadLocalRequest());
 		}catch(Exception e){
 			logger.error("Failed to retrieve profiles for scope coming from organization name " + orgName, e);
 		}
@@ -539,17 +432,13 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 		if(title == null || title.isEmpty())
 			return true; // it's an error somehow
-
 		try{
-
-			String scope = (String)getThreadLocalRequest().getSession().getAttribute(SessionCatalogueAttributes.SCOPE_CLIENT_PORTLET_URL);
-			String idFromTitle = org.gcube.datacatalogue.ckanutillibrary.utils.UtilMethods.fromProductTitleToName(title);
+			String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+			String idFromTitle = UtilMethods.fromProductTitleToName(title);
 			return getCatalogue(scope).existProductWithNameOrId(idFromTitle);
-
 		}catch(Exception e){
 			logger.error("Unable to check if such a dataset id already exists", e);
 		}
-
 		return false;
 	}
 
@@ -560,7 +449,6 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	private String getScopeFromOrgName(String orgName){
 
 		logger.debug("Request for scope related to orgName " + orgName + "[ map that will be used is " + mapOrganizationScope.toString() + " ]");
-
 		if(orgName == null || orgName.isEmpty())
 			throw new IllegalArgumentException("orgName cannot be empty or null!");
 
@@ -570,19 +458,125 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			toReturn = mapOrganizationScope.get(orgName);
 		else{
 			try{
-
 				String evaluatedScope = Utils.retrieveScopeFromOrganizationName(orgName);
 				mapOrganizationScope.put(orgName, evaluatedScope);
 				toReturn = evaluatedScope;
-
 			}catch(Exception e){
 				logger.error("Failed to retrieve scope from OrgName for organization " + orgName, e);
 			}
 		}
-
-
 		logger.debug("Returning scope " + toReturn);
 		return toReturn;
-
 	}
+
+	@Override
+	public List<GroupBean> getUserGroups(String orgName) {
+
+		List<GroupBean> toReturn = new ArrayList<GroupBean>();
+
+		if(isWithinPortal()){
+			String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+
+			logger.debug("Request for user " + username + " groups. Organization name is "  + orgName);
+
+			// get http session
+			HttpSession httpSession = getThreadLocalRequest().getSession();
+			String scope =  orgName != null ? getScopeFromOrgName(orgName) : Utils.getScopeFromClientUrl(getThreadLocalRequest());
+
+			// check if they are in session
+			String keyPerScopeGroups = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_GROUPS_MEMBER, scope);
+
+			if(httpSession.getAttribute(keyPerScopeGroups) != null){
+				toReturn = (List<GroupBean>)httpSession.getAttribute(keyPerScopeGroups);
+				logger.info("Found user's groups in session " + toReturn);
+			}else{
+
+				DataCatalogue catalogue = getCatalogue(scope);
+				String apiKey = catalogue.getApiKeyFromUsername(username);
+				Map<String, Map<CkanGroup, RolesCkanGroupOrOrg>> mapRoleGroup = catalogue.getUserRoleByGroup(username, apiKey);
+				Set<Entry<String, Map<CkanGroup, RolesCkanGroupOrOrg>>> set = mapRoleGroup.entrySet();
+				for (Entry<String, Map<CkanGroup, RolesCkanGroupOrOrg>> entry : set) {
+					Set<Entry<CkanGroup, RolesCkanGroupOrOrg>> subSet = entry.getValue().entrySet();
+					for (Entry<CkanGroup, RolesCkanGroupOrOrg> subEntry : subSet) {
+						toReturn.add(new GroupBean(subEntry.getKey().getTitle(), subEntry.getKey().getName()));	
+					}
+				}
+				httpSession.setAttribute(keyPerScopeGroups, toReturn);
+			}
+		}else{
+			logger.warn("Dev mode detected");
+			toReturn = Arrays.asList(new GroupBean("Group title", "aaa"));
+		}
+		return toReturn;
+	}
+
+
+	@Override
+	public boolean isPublisherUser(boolean isWorkspaceRequest) {
+
+		String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+		logger.info("Checking if the user " + username + " can publish or not on the catalogue");
+
+		if(!isWithinPortal()){
+			logger.warn("OUT FROM PORTAL DETECTED RETURNING TRUE");
+			return false;
+		}
+		
+		try{
+
+			HttpSession httpSession = this.getThreadLocalRequest().getSession();
+
+			// retrieve scope per current portlet url
+			String scopePerCurrentUrl = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+
+			// get key per scope
+			String keyPerScopeRole = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_HIGHEST_ROLE, scopePerCurrentUrl);
+			String keyPerScopeOrganizations = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_ORGANIZATIONS_PUBLISH_KEY, scopePerCurrentUrl);
+			String keyPerScopeGroups = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_GROUPS_MEMBER, scopePerCurrentUrl);
+
+			// check if this information was already into session(true means the user has at least in one org
+			// the role editor), false that he is just a member so he cannot publish
+			RolesCkanGroupOrOrg role = (RolesCkanGroupOrOrg) httpSession.getAttribute(keyPerScopeRole);
+
+			// if the attribute was already set..
+			if(role != null)
+				return !role.equals(RolesCkanGroupOrOrg.MEMBER);
+			else{
+
+				try{
+
+					GroupManager gm = new LiferayGroupManager();
+					String groupName = gm.getGroup(gm.getGroupIdFromInfrastructureScope(scopePerCurrentUrl)).getGroupName();
+
+					// we build up also a list that keeps track of the scopes (orgs) in which the user has role ADMIN/EDITOR
+					List<OrganizationBean> orgsInWhichAtLeastEditorRole = new ArrayList<OrganizationBean>();
+					role = Utils.getHighestRole(scopePerCurrentUrl, username, groupName, this, orgsInWhichAtLeastEditorRole);
+
+					// if he is an admin/editor preload:
+					// 1) organizations in which he can publish (the widget will find these info in session)
+					if(!role.equals(RolesCkanGroupOrOrg.MEMBER)){
+						httpSession.setAttribute(keyPerScopeOrganizations, orgsInWhichAtLeastEditorRole);
+						String orgName = scopePerCurrentUrl.split("/")[scopePerCurrentUrl.split("/").length - 1];
+						httpSession.setAttribute(keyPerScopeGroups, getUserGroups(orgName));
+					}
+				}catch(Exception e){
+					logger.error("Unable to retrieve the role information for this user. Returning FALSE", e);
+					return false;
+				}
+			}
+
+			// set role in session for this scope
+			httpSession.setAttribute(keyPerScopeRole, role);
+
+			logger.info("Does the user have the right to publish on the catalogue? " + role);
+			return !role.equals(RolesCkanGroupOrOrg.MEMBER);
+			
+		}catch(Exception e){
+			logger.error("Failed to check the user's role", e);
+		}
+
+		// return false
+		return false;
+	}
+
 }
\ No newline at end of file
